@@ -59,8 +59,8 @@ dwmHelper <- function(x, combos, data, grpBy, totals, SE){
                 bcStrat = mean(bcPlot, na.rm = TRUE),
                 bpStrat = mean(bpPlot, na.rm = TRUE),
                 bStrat = mean(bPlot, na.rm = TRUE),
-                cdStrat = mean(bdPlot, na.rm = TRUE),
-                clStrat = mean(blPlot, na.rm = TRUE),
+                cdStrat = mean(cdPlot, na.rm = TRUE),
+                clStrat = mean(clPlot, na.rm = TRUE),
                 csmStrat = mean(csmPlot, na.rm = TRUE),
                 cmdStrat = mean(cmdPlot, na.rm = TRUE),
                 clgStrat = mean(clgPlot, na.rm = TRUE),
